@@ -27,6 +27,7 @@
 #include "mauilist.h"
 #include "mauimodel.h"
 #include "notify.h"
+#include "style.h"
 #include "tabview.h"
 
 #ifdef Q_OS_ANDROID
@@ -54,15 +55,12 @@ QUrl MauiKit::componentUrl(const QString &fileName) const
 void MauiKit::initializeEngine(QQmlEngine *engine, const char *uri)
 {
     Q_UNUSED(uri);
-    this->initResources();
-
     KLocalizedString::setApplicationDomain("mauikit");
     engine->rootContext()->setContextObject(new KLocalizedContext(engine));
 }
 
 void MauiKit::registerTypes(const char *uri)
-{   
-    qmlRegisterSingletonType(componentUrl(QStringLiteral("Style.qml")), uri, 1, 0, "Style");
+{
     qmlRegisterType(componentUrl(QStringLiteral("ToolBar.qml")), uri, 1, 0, "ToolBar");
     qmlRegisterType(componentUrl(QStringLiteral("ApplicationWindow.qml")), uri, 1, 0, "ApplicationWindow");
     qmlRegisterType(componentUrl(QStringLiteral("Page.qml")), uri, 1, 0, "Page");
@@ -112,10 +110,10 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("AppViews.qml")), uri, 1, 1, "AppViews");
     qmlRegisterType(componentUrl(QStringLiteral("AppViewLoader.qml")), uri, 1, 1, "AppViewLoader");
     qmlRegisterType(componentUrl(QStringLiteral("AltBrowser.qml")), uri, 1, 1, "AltBrowser");
-
-    qmlRegisterType(componentUrl(QStringLiteral("labs/TabsBrowser.qml")), uri, 1, 1, "TabsBrowser");
     qmlRegisterType(componentUrl(QStringLiteral("labs/SettingsDialog.qml")), uri, 1, 1, "SettingsDialog");
     qmlRegisterType(componentUrl(QStringLiteral("labs/SettingsSection.qml")), uri, 1, 1, "SettingsSection");
+    qmlRegisterType(componentUrl(QStringLiteral("labs/ImageViewer.qml")), uri, 1, 1, "ImageViewer");
+    qmlRegisterType(componentUrl(QStringLiteral("labs/AnimatedImageViewer.qml")), uri, 1, 1, "AnimatedImageViewer");
 
     /** 1.2 **/
     qmlRegisterType(componentUrl(QStringLiteral("labs/SettingTemplate.qml")), uri, 1, 2, "SettingTemplate");
@@ -142,13 +140,9 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("SplitViewItem.qml")), uri, 1, 3, "SplitViewItem");
     qmlRegisterType(componentUrl(QStringLiteral("ProgressIndicator.qml")), uri, 1, 3, "ProgressIndicator");
 
-    //2.0
     qmlRegisterType(componentUrl(QStringLiteral("labs/MenuItemActionRow.qml")), uri, 1, 3, "MenuItemActionRow");
     qmlRegisterType(componentUrl(QStringLiteral("labs/GalleryRollTemplate.qml")), uri, 1, 3, "GalleryRollTemplate");
 
-    /** 2.0 **/
-    qmlRegisterType(componentUrl(QStringLiteral("labs/RowMenuItems.qml")), uri, 2, 0, "RowMenuItems");
-
     /// NON UI CONTROLS
     qmlRegisterUncreatableType<AppView>(uri, 1, 1, "AppView", "Cannot be created AppView");
     qmlRegisterUncreatableType<TabViewInfo>(uri, 1, 3, "TabViewInfo", "Cannot be created TabView");
@@ -201,7 +195,7 @@ void MauiKit::registerTypes(const char *uri)
 
     qmlRegisterType<WindowShadow>(uri, 1, 0, "WindowShadow");
     qmlRegisterType<WindowBlur>(uri, 1, 0, "WindowBlur");
-    
+
     /** DATA MODELING TEMPLATED INTERFACES **/
     qmlRegisterAnonymousType<MauiList>(uri, 1); // ABSTRACT BASE LIST
     qmlRegisterType<MauiModel>(uri, 1, 0, "BaseModel"); // BASE MODEL
@@ -214,10 +208,14 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType<Notify>(uri, 1, 3, "Notify");
     qmlRegisterType<NotifyAction>(uri, 1, 3, "NotifyAction");
 
+    qmlRegisterSingletonType<Style>(uri, 1, 0, "Style", [] (QQmlEngine *, QJSEngine *)
+    {
+        return Style::instance ();
+    });
+
     qmlRegisterUncreatableType<MauiApp>(uri, 1, 0, "App", "Cannot be created App");
-    qmlRegisterSingletonType<Handy>(uri, 1, 0, "Handy", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
-        Q_UNUSED(engine)
-        Q_UNUSED(scriptEngine)
+    qmlRegisterSingletonType<Handy>(uri, 1, 0, "Handy", [](QQmlEngine *, QJSEngine *)
+    {
         return new Handy;
     });
 
@@ -232,13 +230,4 @@ void MauiKit::registerTypes(const char *uri)
     qmlProtectModule(uri, 1);
 }
 
-void MauiKit::initResources()
-{
-#if defined Q_OS_ANDROID || defined Q_OS_MACOS || defined Q_OS_WIN
-    Q_INIT_RESOURCE(mauikit);
-    Q_INIT_RESOURCE(style);
-    Q_INIT_RESOURCE(icons);
-#endif
-}
-
 //#include "moc_mauikit.cpp"
