@@ -3,7 +3,7 @@
 #ifdef Q_OS_ANDROID
 #include "mauiandroid.h"
 #elif defined Q_OS_MAC
-#include "mauimacos.h"
+//#include "mauimacos.h"
 #elif defined Q_OS_WIN
 #include "mauiwindows.h"
 #elif defined Q_OS_IOS
@@ -12,6 +12,10 @@
 #include "mauilinux.h"
 #endif
 
+#include <QCoreApplication>
+
+Platform *Platform::m_instance = nullptr;
+
 Platform *Platform::qmlAttachedProperties(QObject *object)
 {
     Q_UNUSED(object)
@@ -24,7 +28,7 @@ Platform::Platform(QObject *parent)
 #ifdef Q_OS_ANDROID
     m_platform(new MAUIAndroid(this))
 #elif defined Q_OS_MAC
-    m_platform(new MAUIMacOS(this))
+    m_platform(nullptr)
 #elif defined Q_OS_WIN
     m_platform(new MAUIWindows(this))
 #elif defined Q_OS_IOS
@@ -34,6 +38,13 @@ Platform::Platform(QObject *parent)
 #endif
 {
     connect(m_platform, &AbstractPlatform::shareFilesRequest, this, &Platform::shareFilesRequest);
+
+    connect(qApp, &QCoreApplication::aboutToQuit, []()
+    {
+        qDebug() << "Lets remove MauiApp singleton instance";
+        delete m_instance;
+        m_instance = nullptr;
+    });
 }
 
 void Platform::shareFiles(const QList<QUrl> &urls)
