@@ -33,8 +33,11 @@
 #include <QFileSystemWatcher>
 #endif
 
-#if defined Q_OS_ANDROID || defined Q_OS_MACOS || defined Q_OS_WIN
+#if defined BUNDLE_LUV_ICONS
 #include <QIcon>
+#endif
+
+#if defined BUNDLE_MAUI_STYLE
 #include <QQuickStyle>
 #endif
 
@@ -43,9 +46,10 @@
 MauiApp *MauiApp::m_instance = nullptr;
 
 MauiApp::MauiApp()
-: QObject(nullptr)
-, m_controls(new CSDControls(this))
+    : QObject(nullptr)
+    , m_controls(new CSDControls(this))
 {
+    qDebug() << "CREATING INSTANCE OF MAUI APP";
     connect(qApp, &QCoreApplication::aboutToQuit, []()
     {
         qDebug() << "Lets remove MauiApp singleton instance";
@@ -53,10 +57,8 @@ MauiApp::MauiApp()
         m_instance = nullptr;
     });
     
-    #if defined Q_OS_ANDROID || defined Q_OS_MACOS || defined Q_OS_WIN
     setDefaultMauiStyle();
-    #endif
-    
+
     //    qputenv("QT_QUICK_CONTROLS_CONF",  "://qtquickcontrols2.conf");
 }
 
@@ -67,7 +69,6 @@ QString MauiApp::getMauikitVersion()
 
 QString MauiApp::getIconName() const
 {
-    qDebug() << "REQUESTING ICONNAME" << m_iconName << this;
     return m_iconName;
 }
 
@@ -101,12 +102,17 @@ KAboutData MauiApp::getAbout() const
 
 void MauiApp::setDefaultMauiStyle()
 {
-#if defined QICON_H && defined QQUICKSTYLE_H
+#if defined BUNDLE_LUV_ICONS
+    Q_INIT_RESOURCE(icons);
     QIcon::setThemeSearchPaths({":/icons/luv-icon-theme"});
     QIcon::setThemeName("Luv");
-    qDebug() << QIcon::themeSearchPaths() << QIcon::hasThemeIcon("sidebar-expand");
+#endif
+    
+#if defined BUNDLE_MAUI_STYLE
+    Q_INIT_RESOURCE(style);
     QQuickStyle::setStyle("maui-style");
-    #endif
+    qDebug() << QQuickStyle::name();
+#endif
 }
 
 QQuickWindow * MauiApp::window() const
@@ -143,12 +149,23 @@ MauiApp *MauiApp::qmlAttachedProperties(QObject *object)
 
 CSDControls::CSDControls(QObject *parent) : QObject (parent)
 {
-    this->setEnableCSD(UTIL::loadSettings("CSD", "GLOBAL", m_enableCSD, true).toBool());
+#if !defined Q_OS_ANDROID || defined Q_OS_LINUX // ignore csd for those
+    if (qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE"))
+    {
+        if (QByteArrayList {"0", "false"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE")))
+        {
+                        this->setEnableCSD(UTIL::loadSettings("CSD", "GLOBAL", m_enableCSD, true).toBool());
+        }
+    }else
+    {
+        this->setEnableCSD(UTIL::loadSettings("CSD", "GLOBAL", m_enableCSD, true).toBool());
+    }
+#endif
 }
 
 void CSDControls::getWindowControlsSettings()
 {    
-    #if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
     
     m_styleName = UTIL::loadSettings("CSDStyle", "GLOBAL", "Nitrux", true).toString();
     auto confFile = QStandardPaths::locate (QStandardPaths::GenericDataLocation, QString("org.mauikit.controls/csd/%1/config.conf").arg(m_styleName));
@@ -161,8 +178,8 @@ void CSDControls::getWindowControlsSettings()
         conf.beginGroup ("Decoration");
         m_source = dir.toString()+"/"+ conf.value("Source").toString();
         m_borderRadius = conf.value ("BorderRadius", 8).toInt();
-        conf.endGroup ();        
-    }    
+        conf.endGroup ();
+    }
     
     qDebug() << "CSD QML SOURCXE" << m_source;
     auto kconf = KSharedConfig::openConfig("kwinrc");
@@ -178,14 +195,14 @@ void CSDControls::getWindowControlsSettings()
         emit this->rightWindowControlsChanged();
     }
     
-    #elif defined Q_OS_MACOS || defined Q_OS_ANDROID
+#elif defined Q_OS_MACOS || defined Q_OS_ANDROID
     m_leftWindowControls = QStringList {"X", "I", "A"};
     emit this->leftWindowControlsChanged();
     
-    #elif defined Q_OS_WIN32
+#elif defined Q_OS_WIN32
     //   m_rightWindowControls = QStringList {"I", "A", "X"};
     emit this->rightWindowControlsChanged();
-    #endif
+#endif
 }
 
 bool CSDControls::enableCSD() const
@@ -195,32 +212,17 @@ bool CSDControls::enableCSD() const
 
 void CSDControls::setEnableCSD(const bool &value)
 {
-    #if defined Q_OS_ANDROID || defined Q_OS_IOS // ignore csd for those
-    Q_UNUSED(value)
-    return;
-    #else
-    
-    if (qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE"))
-    {
-        if (QByteArrayList {"1", "true"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE")))
-        {
-            m_enableCSD = false;
-            return;
-        }
-    }else
-    {        
         if (m_enableCSD == value)
             return;
         
         m_enableCSD = value;
-    }
+    
     
     emit enableCSDChanged();
     
     if (m_enableCSD) {
         getWindowControlsSettings();
     }
-    #endif
 }
 
 QUrl CSDControls::source() const
@@ -242,7 +244,7 @@ CSDButton::CSDButton(QObject *parent): QObject(parent)
 {
     connect(this, &CSDButton::typeChanged, this, &CSDButton::setSources);
     connect(this, &CSDButton::stateChanged, this, &CSDButton::requestCurrentSource);
-    m_style = MauiApp::instance()->controls()->styleName();  
+    m_style = MauiApp::instance()->controls()->styleName();
 }
 
 QUrl CSDButton::source() const
@@ -281,7 +283,7 @@ QUrl CSDButton::extractStateValue(QSettings &settings, const CSDButton::CSDButto
     settings.beginGroup (mapButtonType (m_type));
     res =  m_dir.toString ()+"/"+settings.value (mapButtonState (state)).toString ();
     settings.endGroup ();
-       
+
     if(QFile::exists (res.toLocalFile ()))
     {
         return res;
@@ -301,12 +303,12 @@ QString CSDButton::mapButtonType(const CSDButtonType &type)
 {
     switch(type)
     {
-        case Close: return "Close";
-        case Maximize: return "Maximize";
-        case Minimize: return "Minimize";
-        case Restore: return "Restore";
-        case Fullscreen: return "Fullscreen";
-        default: return "";
+    case Close: return "Close";
+    case Maximize: return "Maximize";
+    case Minimize: return "Minimize";
+    case Restore: return "Restore";
+    case Fullscreen: return "Fullscreen";
+    default: return "";
     }
 }
 
@@ -314,12 +316,12 @@ QString CSDButton::mapButtonState(const CSDButtonState &type)
 {
     switch(type)
     {
-        case Normal: return "Normal";
-        case Hover: return "Hover";
-        case Pressed: return "Pressed";
-        case Backdrop: return "Backdrop";
-        case Disabled: return "Disabled";
-        default: return "";
+    case Normal: return "Normal";
+    case Hover: return "Hover";
+    case Pressed: return "Pressed";
+    case Backdrop: return "Backdrop";
+    case Disabled: return "Disabled";
+    default: return "";
     }
 }
 
