@@ -18,6 +18,7 @@
 
 #ifndef MAUIAPP_H
 #define MAUIAPP_H
+
 #include <QObject>
 #include <QQmlEngine>
 
@@ -25,7 +26,6 @@
 
 #include "mauikit_export.h"
 
-#include <QColor>
 #include <QSettings>
 
 #if defined Q_OS_LINUX && !defined Q_OS_ANDROID
@@ -46,9 +46,13 @@
  * }
  */
 
+class QQuickWindow;
+class QQuickItem;
 class CSDButton : public QObject
 {
   Q_OBJECT
+  Q_DISABLE_COPY(CSDButton)
+  
   Q_PROPERTY(bool isHovered READ isHovered WRITE setIsHovered NOTIFY isHoveredChanged)
   Q_PROPERTY(bool isMaximized READ isMaximized WRITE setIsMaximized NOTIFY isMaximizedChanged)
   Q_PROPERTY(bool isPressed READ isPressed WRITE setIsPressed NOTIFY isPressedChanged)
@@ -99,6 +103,9 @@ public:
   CSDButton::CSDButtonType type() const;
   void setType(CSDButton::CSDButtonType newType);
 
+public slots:
+  CSDButton::CSDButtonType mapType(const QString &value);
+
 private:
   CSDButtonType m_type = CSDButtonType::None;
   QUrl m_source;
@@ -121,6 +128,7 @@ private:
   void setSources();
   void requestCurrentSource();
 
+  QString m_style;
 
 signals:
   void stateChanged();
@@ -135,12 +143,15 @@ signals:
 class CSDControls : public QObject
 {
   Q_OBJECT
-
+  Q_DISABLE_COPY(CSDControls)
+  
   Q_PROPERTY(bool enableCSD READ enableCSD WRITE setEnableCSD NOTIFY enableCSDChanged)
+  Q_PROPERTY(QUrl source READ source CONSTANT FINAL)
+  Q_PROPERTY(int borderRadius READ borderRadius CONSTANT FINAL)
+  Q_PROPERTY(QString styleName READ styleName CONSTANT FINAL)
   Q_PROPERTY(QStringList leftWindowControls MEMBER m_leftWindowControls NOTIFY leftWindowControlsChanged FINAL)
   Q_PROPERTY(QStringList rightWindowControls MEMBER m_rightWindowControls NOTIFY rightWindowControlsChanged FINAL)
 
-
 public:
   typedef QHash<CSDButton::CSDButtonType, CSDButton*> CSDButtons;
 
@@ -160,9 +171,15 @@ public:
      * @param value
      */
   void setEnableCSD(const bool &value);
+  int borderRadius() const;
+  QUrl source() const;
+  QString styleName() const;
 
 private:
   bool m_enableCSD = false;
+  QUrl m_source;
+  int m_borderRadius;
+  QString m_styleName = "Nitrux";
   QStringList m_leftWindowControls;
   QStringList m_rightWindowControls;
 
@@ -179,12 +196,17 @@ class Notify;
 class MAUIKIT_EXPORT MauiApp : public QObject
 {
   Q_OBJECT
+  Q_DISABLE_COPY(MauiApp)
+  
   Q_PROPERTY(KAboutData about READ getAbout CONSTANT FINAL)
   Q_PROPERTY(QString iconName READ getIconName WRITE setIconName NOTIFY iconNameChanged)
   Q_PROPERTY(QString donationPage READ getDonationPage WRITE setDonationPage NOTIFY donationPageChanged)
   Q_PROPERTY(CSDControls * controls READ controls CONSTANT FINAL)
   Q_PROPERTY(QString mauikitVersion READ getMauikitVersion CONSTANT FINAL)
-
+    Q_PROPERTY(bool translucencyAvailable READ translucencyAvailable NOTIFY translucencyAvailableChanged)
+//   Q_PROPERTY(QQuickWindow *window READ window WRITE setWindow NOTIFY windowChanged)
+//   Q_PROPERTY(QQuickItem *windowPage READ windowPage WRITE setWindowPage NOTIFY windowPageChanged)
+  
 public:
   static MauiApp *qmlAttachedProperties(QObject *object);
 
@@ -197,8 +219,6 @@ public:
     return m_instance;
   }
 
-  MauiApp(const MauiApp &) = delete;
-  MauiApp &operator=(const MauiApp &) = delete;
   MauiApp(MauiApp &&) = delete;
   MauiApp &operator=(MauiApp &&) = delete;
 
@@ -242,25 +262,31 @@ public:
      * Returns a model of the credits represented as a QVariantList, some of the fields used are: name, email, year.
      * @return
      */
-  KAboutData getAbout() const
-  {
-    return KAboutData::applicationData();
-  }
+  KAboutData getAbout() const;
 
   static void setDefaultMauiStyle();
 
   CSDControls *controls() const;
   
+  QQuickWindow *window() const;  
+  QQuickItem *windowPage() const;
+  
+  bool translucencyAvailable() const;
+  void setTranslucencyAvailable(const bool &value);
+
 private:
   static MauiApp *m_instance;
   MauiApp();
   CSDControls * m_controls;
   QString m_iconName;
   QString m_donationPage;
+  
+  bool m_translucencyAvailable = false;
 
 signals:
   void iconNameChanged();
   void donationPageChanged();
+  void translucencyAvailableChanged(bool translucencyAvailable);
 };
 
 QML_DECLARE_TYPEINFO(MauiApp, QML_HAS_ATTACHED_PROPERTIES)
